package Acme::MadokaMagica::TvMembers::AkemiHomura;
use parent qw/Acme::MadokaMagica::TvMembers/;
use strict;
use warnings;
use utf8;


1;

__DATA__

@@ AkemiHomura
firstname: ほむら
lastname: 暁美
age: 14
birthday: 3/12
blood_type: A
cv: 斎藤千和
say: それには及ばないわ
witchename: Homulilly
color: purple
