package Acme::MadokaMagica::TvMembers::KanameMadoka;
use parent 'Acme::MadokaMagica::TvMembers';
use strict;
use warnings;
use utf8;


1;

__DATA__

@@ KanameMadoka
firstname: まどか
lastname: 鹿目
age: 14
birthday: 10/3
blood_type: A
cv: 悠木碧
say: ウェヒヒww
witchename: Kriemhild_Gretchen
color: Pink
