package Acme::MadokaMagica::TvMembers::MikiSayaka;
use parent 'Acme::MadokaMagica::TvMembers';
use utf8;


1;

__DATA__

@@ MikiSayaka
firstname: さやか
lastname: 美樹
age: 14
birthday: 8/16
blood_type: A
cv: 喜多村英梨
say: あたしってほんとバカ
witchename: Oktavia_Von_Seckendorff
color: Blue
