use strict;
use warnings;
use utf8;

use Acme::MadokaMagica;
use Test::More;

subtest 'Soulgem' => sub{
    subtest 'alone_members' => sub {
        my ($mami) = Acme::MadokaMagica->alone_members;
        is ref $mami,'Acme::MadokaMagica::TvMembers::TomoeMami';
        is $mami->color,'yellow';

































































































        is $mami->color,undef;

    };

    subtest 'members_of' => sub {
        my ($kyoko,) = Acme::MadokaMagica->members_of($Acme::MadokaMagica::KyoSaya);
        is ref $kyoko,'Acme::MadokaMagica::TvMembers::SakuraKyoko';
        is $kyoko->color,'Red';

































































































        is $kyoko->color,undef;
    };
};

done_testing;
